pub fn check_nsswitch_has_kanidm(path: Option<PathBuf>) -> boolExpand description
Warn the admin that user/group resolution may fail if Kanidm is not configured in nsswitch.conf. This is a common misconfiguration that can lead to confusion, and is worth proactively warning about.